netapp_ontap.models.raid_group_disk API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.raid_group_disk`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class RaidGroupDiskSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the RaidGroupDisk object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `disk: Disk GET`

    The disk field of the raid_group_disk.

  `position: str GET`

    The position of the disk within the RAID group.

    Valid choices:

    - data
    - parity
    - dparity
    - tparity
    - copy
  `state: str GET`

    The state of the disk within the RAID group.

    Valid choices:

    - normal
    - failed
    - zeroing
    - copy
    - replacing
    - evacuating
    - prefail
    - offline
    - reconstructing
  `type: str GET`

    Disk interface type

    Valid choices:

    - ata
    - bsas
    - fcal
    - fsas
    - lun
    - sas
    - msata
    - ssd
    - vmdisk
    - unknown
    - ssd_cap
    - ssd_nvm
    - ssd_zns
  `usable_size: Size GET`

    Size in bytes that is usable by the aggregate.

    Example: 947912704